@@ -65,7 +65,7 @@ def get_locale_lang():
         lang = locale.getdefaultlocale(('LANGUAGE', 'LC_ALL', 'LANG'))[0]
         if not lang and sys.platform == "darwin":
            lang = osx_lang()
-        if lang and _(''):
+        if lang:
             return data.simplify_to_common(lang)
     except Exception:
         logging.exception("Could not get locale")
