@@ -40,7 +40,6 @@ class MainController(BaseController):
     # INITIALIZERS #
     def __init__(self):
         GObjectWrapper.__init__(self)
-        self.store_controller = None # This is set by StoreController itself when it is created
         self._force_saveas = False
 
         self._lang_controller = None
@@ -50,6 +49,7 @@ class MainController(BaseController):
         self._store_controller = None
         self._undo_controller = None
         self._unit_controller = None
+        self._welcomescreen_controller = None
         self.view = MainView(self)
 
     # ACCESSORS #
@@ -147,10 +147,20 @@ class MainController(BaseController):
         self.emit('controller-registered', self._unit_controller)
     unit_controller = property(_get_unit_controller, _set_unit_controller)
 
+    def _get_welcomescreen_controller(self):
+        return self._welcomescreen_controller
+    def _set_welcomescreen_controller(self, value):
+        self._welcomescreen_controller = value
+        self.emit('controller-registered', self._welcomescreen_controller)
+    welcomescreen_controller = property(_get_welcomescreen_controller, _set_welcomescreen_controller)
+
+
     # METHODS #
-    def open_file(self, filename, uri=''):
+    def open_file(self, filename=None, uri=''):
         """Open the file given by C{filename}.
             @returns: The filename opened, or C{None} if an error has occurred."""
+        if filename is None:
+            return self.view.open_file()
         if self.store_controller.is_modified():
             response = self.view.show_save_confirm_dialog()
             if response == 'save':
@@ -176,8 +186,13 @@ class MainController(BaseController):
             self.show_error(
                 filename + ":\n" + _("Could not open file.\n\n%(error_message)s\n\nTry opening a different file.") % {'error_message': str(exc)}
             )
+            self.close_file()
             return False
 
+    def open_tutorial(self):
+        filename = pan_app.get_abs_data_filename(["virtaal", "tutorial.pot"])
+        self.open_file(filename)
+
     def save_file(self, filename=None):
         try:
             self.store_controller.save_file(filename)
@@ -191,6 +206,16 @@ class MainController(BaseController):
                 _("Could not save file.\n\n%(error_message)s" % {'error_message': str(exc)})
             )
 
+    def close_file(self):
+        if self.store_controller.is_modified():
+            response = self.view.show_save_confirm_dialog()
+            if response == 'save':
+                self.store_controller.save_file()
+            elif response == 'cancel':
+                return False
+            # Unnecessary to test for 'discard'
+        self.store_controller.close_file()
+
     def revert_file(self, filename=None):
         confirm = self.show_prompt(_("Reload File"), _("Reload file from last saved copy and lose all changes?"))
         if not confirm:
