@@ -37,6 +37,7 @@ class StoreController(BaseController):
     __gsignals__ = {
         'store-loaded': (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ()),
         'store-saved':  (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ()),
+        'store-closed': (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ()),
     }
 
     # INITIALIZERS #
@@ -94,13 +95,10 @@ class StoreController(BaseController):
             return
 
         i = 0
-        for storeunit in self.get_store().get_units():
-            if storeunit == unit:
-                break
-            i += 1
-
-        if i >= len(self.get_store().get_units()):
-            logging.debug('Unit not found.')
+        try:
+            i = self.store.get_units().index(unit)
+        except Exception, exc:
+            logging.debug('Unit not found:\n%s' % (exc))
 
         if force:
             self.cursor.force_index(i)
@@ -137,6 +135,14 @@ class StoreController(BaseController):
         self.main_controller.set_saveable(False)
         self.emit('store-saved')
 
+    def close_file(self):
+        self.store = None
+        self._modified = False
+        self.main_controller.set_saveable(False)
+        self.view.hide() # This MUST be called BEFORE `self.cursor = None`
+        self.emit('store-closed') # This should be emitted BEFORE `self.cursor = None` to allow any other modules to disconnect from the cursor
+        self.cursor = None
+
     def revert_file(self):
         self.open_file(self.store.filename)
 
