@@ -47,7 +47,6 @@ class UndoController(BaseController):
 
         self.enabled = True
         self.model = UndoModel(self)
-        self._paste_undo_info = None
 
         self._setup_key_bindings()
         self._connect_undo_signals()
@@ -56,13 +55,14 @@ class UndoController(BaseController):
         # First connect to the unit controller
         self.unit_controller.connect('unit-delete-text', self._on_unit_delete_text)
         self.unit_controller.connect('unit-insert-text', self._on_unit_insert_text)
-        self.unit_controller.connect('unit-paste-start', self._on_unit_paste_start)
-        self.main_controller.store_controller.connect('store-loaded', self._on_store_loaded)
+        self.main_controller.store_controller.connect('store-closed', self._on_store_loaded_closed)
+        self.main_controller.store_controller.connect('store-loaded', self._on_store_loaded_closed)
 
         mainview = self.main_controller.view
         mainview.gui.get_widget('menu_edit').set_accel_group(self.accel_group)
-        mainview.gui.get_widget('mnu_undo').set_accel_path('<Virtaal>/Edit/Undo')
-        mainview.gui.get_widget('mnu_undo').connect('activate', self._on_undo_activated)
+        self.mnu_undo = mainview.gui.get_widget('mnu_undo')
+        self.mnu_undo.set_accel_path('<Virtaal>/Edit/Undo')
+        self.mnu_undo.connect('activate', self._on_undo_activated)
 
     def _setup_key_bindings(self):
         """Setup Gtk+ key bindings (accelerators).
@@ -100,19 +100,15 @@ class UndoController(BaseController):
         current_text = textbox.elem.copy()
         unitview = self.unit_controller.view
 
-        curpos = textbox.buffer.props.cursor_position
-        targetn = 0
-        for tgt in unitview.targets:
-            if tgt is textbox:
-                break
-            targetn += 1
+        curpos = textbox.get_cursor_position()
+        targetn = unitview.targets.index(textbox)
         def undo_set_text(unit):
             textbox.elem.sub = current_text.sub
 
         self.model.push({
             'action': undo_set_text,
             'cursorpos': curpos,
-            'desc': 'Set target %d text to %s' % (targetn, repr(textbox.elem)),
+            'desc': 'Set target %d text to %s' % (targetn, repr(current_text)),
             'targetn': targetn,
             'unit': unitview.unit
         })
@@ -164,7 +160,7 @@ class UndoController(BaseController):
         undo_info['action'](undo_info['unit'])
         self._enable_unit_signals()
 
-        textbox = self.unit_controller.view.targets[self.unit_controller.view.focused_target_n]
+        textbox = self.unit_controller.view.targets[undo_info['targetn']]
         def refresh():
             textbox.refresh_cursor_pos = undo_info['cursorpos']
             textbox.refresh()
@@ -179,7 +175,11 @@ class UndoController(BaseController):
 
 
     # EVENT HANDLERS #
-    def _on_store_loaded(self, storecontroller):
+    def _on_store_loaded_closed(self, storecontroller):
+        if storecontroller.store is not None:
+            self.mnu_undo.set_sensitive(True)
+        else:
+            self.mnu_undo.set_sensitive(False)
         self.model.clear()
 
     @if_enabled
@@ -196,11 +196,6 @@ class UndoController(BaseController):
 
     @if_enabled
     def _on_unit_delete_text(self, unit_controller, unit, deleted, parent, offset, cursor_pos, elem, target_num):
-        if self._paste_undo_info:
-            self.model.push(self._paste_undo_info)
-            self._paste_undo_info = None
-            return
-
         def undo_action(unit):
             #logging.debug('(undo) %s.insert(%d, "%s")' % (repr(elem), start_offset, deleted))
             if parent is None:
@@ -226,9 +221,6 @@ class UndoController(BaseController):
 
     @if_enabled
     def _on_unit_insert_text(self, unit_controller, unit, ins_text, offset, elem, target_num):
-        if self._paste_undo_info:
-            return
-
         #logging.debug('_on_unit_insert_text(ins_text="%s", offset=%d, elem=%s, target_n=%d)' % (ins_text, offset, repr(elem), target_num))
 
         def undo_action(unit):
@@ -249,15 +241,3 @@ class UndoController(BaseController):
             'targetn': target_num,
             'cursorpos': offset
         })
-
-    @if_enabled
-    def _on_unit_paste_start(self, _unit_controller, unit, old_text, offsets, target_num):
-        if offsets['insert_offset'] == offsets['selection_offset']:
-            # If there is no selection, a paste is equivalent to an insert action
-            return
-
-        self._paste_undo_info = {
-            'unit': unit,
-            'targetn': target_num,
-            'cursorpos': offsets['insert_offset']
-        }
