@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2008-2009 Zuza Software Foundation
+# Copyright 2008-2010 Zuza Software Foundation
 #
 # This file is part of Virtaal.
 #
@@ -29,6 +29,7 @@ from virtaal.controllers import Cursor
 
 from basemode import BaseMode
 from virtaal.views import markup
+from virtaal.views.theme import current_theme
 
 
 class SearchMode(BaseMode):
@@ -51,6 +52,9 @@ class SearchMode(BaseMode):
 
         self._create_widgets()
         self._setup_key_bindings()
+        # We alter the colours of ent_search, so let's listen for changes on
+        # ent_replace to ensure we are always compliant to the style.
+        self.ent_replace.connect('style-set', self._on_style_set)
 
         self.matches = []
         self.select_first_match = True
@@ -89,9 +93,6 @@ class SearchMode(BaseMode):
             self.lbl_replace, self.ent_replace, self.btn_replace, self.chk_replace_all
         ]
 
-        self.default_base = gtk.widget_get_default_style().base[gtk.STATE_NORMAL]
-        self.default_text = gtk.widget_get_default_style().text[gtk.STATE_NORMAL]
-
     def _setup_key_bindings(self):
         gtk.accel_map_add_entry("<Virtaal>/Edit/Search", gtk.keysyms.F3, 0)
         gtk.accel_map_add_entry("<Virtaal>/Edit/Search Ctrl+F", gtk.keysyms.F, gtk.gdk.CONTROL_MASK)
@@ -216,7 +217,7 @@ class SearchMode(BaseMode):
             self.matchcursor.index = match_index
         else:
             if self.ent_search.get_text():
-                self.ent_search.modify_base(gtk.STATE_NORMAL, gtk.gdk.color_parse('#f66'))
+                self.ent_search.modify_base(gtk.STATE_NORMAL, gtk.gdk.color_parse(current_theme['warning_bg']))
                 self.ent_search.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse('#fff'))
             else:
                 self.ent_search.modify_base(gtk.STATE_NORMAL, self.default_base)
@@ -319,7 +320,7 @@ class SearchMode(BaseMode):
                 m.part_n == textbox_n
         ]
 
-    def _highlight_textbox_matches(self, textbox):
+    def _highlight_textbox_matches(self, textbox, select_match=True):
         buff = textbox.buffer
         buffstr = textbox.get_text()
         unescaped = markup.unescape(buffstr)
@@ -332,8 +333,8 @@ class SearchMode(BaseMode):
             if tag:
                 tagtable.remove(tag)
             tagtable.add(self._make_highlight_tag())
-        except ValueError:
-            pass
+        except ValueError, ve:
+            logging.exception("(Re-)adding search highlighting tag exception:")
 
         select_iters = []
         for match in self._get_matches_for_textbox(textbox):
@@ -344,7 +345,7 @@ class SearchMode(BaseMode):
             start_iter, end_iter = buff.get_iter_at_offset(start), buff.get_iter_at_offset(end)
             buff.apply_tag_by_name('search_highlight', start_iter, end_iter)
 
-            if textbox.role == 'target' and not select_iters and self.select_first_match:
+            if select_match and textbox.role == 'target' and not select_iters and self.select_first_match:
                 select_iters = [start_iter, end_iter]
 
         if select_iters:
@@ -431,9 +432,15 @@ class SearchMode(BaseMode):
         self._move_match(1)
 
     def _on_search_next(self, *args):
+        # FIXME: Remove the following check when these actions are connected to menu items.
+        if self.controller.main_controller.store_controller.store is None:
+            return
         self._move_match(1)
 
     def _on_search_prev(self, *args):
+        # FIXME: Remove the following check when these actions are connected to menu items.
+        if self.controller.main_controller.store_controller.store is None:
+            return
         self._move_match(-1)
 
     def _on_search_text_changed(self, entry):
@@ -445,14 +452,23 @@ class SearchMode(BaseMode):
 
     def _on_start_search(self, _accel_group, _acceleratable, _keyval, _modifier):
         """This is called via the accelerator."""
+        # FIXME: Remove the following check when these actions are connected to menu items.
+        if self.controller.main_controller.store_controller.store is None:
+            return
         self.controller.select_mode(self)
 
+    def _on_style_set(self, widget, prev_style):
+        self.default_base = widget.style.base[gtk.STATE_NORMAL]
+        self.default_text = widget.style.text[gtk.STATE_NORMAL]
+        self.ent_search.modify_base(gtk.STATE_NORMAL, self.default_base)
+        self.ent_search.modify_text(gtk.STATE_NORMAL, self.default_text)
+
     def _on_textbox_refreshed(self, textbox, elem):
         """Redoes highlighting after a C{StringElem} render destoyed it."""
         if not textbox.props.visible or not unicode(elem):
             return
 
-        self._highlight_textbox_matches(textbox)
+        self._highlight_textbox_matches(textbox, select_match=False)
 
     def _on_unit_modified(self, unit_controller, current_unit):
         unit_matches = self._get_matches_for_unit(current_unit)
