@@ -34,8 +34,8 @@ from basetmmodel import BaseTMModel
 class TMModel(BaseTMModel):
     """This is a libtranslate translation memory model.
 
-    The plugin does the following: intialise libtranslate, get the services, get a session.
-    During operartion is simply queries libtranslate for a translation.  This follows the
+    The plugin does the following: initialise libtranslate, get the services, get a session.
+    During operation it simply queries libtranslate for a translation.  This follows the
     pattern outlined in file:///usr/share/gtk-doc/html/libtranslate/tutorials.html (sorry
     no online version found, use the one packaged with libtranslate).
     """
@@ -79,7 +79,8 @@ class TMModel(BaseTMModel):
 
 
     # METHODS #
-    def query(self, tmcontroller, query_str):
+    def query(self, tmcontroller, unit):
+        query_str = unit.source
         translation = []
         err = c_int()
         result = self.lt.translate_session_translate_text(
@@ -87,6 +88,8 @@ class TMModel(BaseTMModel):
             self.source_lang, self.target_lang,
             None, None, err
         )
+        if not isinstance(result, unicode):
+            result = unicode(result, 'utf-8') # XXX: The encoding is just a guess
         if result is None:
             # TODO handle errors and cleanup errors
             logging.warning("An error occured while getting a translation: %s" % err)
