@@ -59,7 +59,8 @@ class TMModel(BaseTMModel):
     def set_target_lang(self, language):
         self.tmclient.set_target_lang(language)
 
-    def query(self, tmcontroller, query_str):
+    def query(self, tmcontroller, unit):
+        query_str = unit.source
         if self.cache.has_key(query_str):
             self.emit('match-found', query_str, self.cache[query_str])
         else:
@@ -68,6 +69,8 @@ class TMModel(BaseTMModel):
     def _handle_matches(self, widget, query_str, matches):
         """Handle the matches when returned from self.tmclient."""
         for match in matches:
+            if not isinstance(match['target'], unicode):
+                match['target'] = unicode(match['target'], 'utf-8')
             if 'tmsource' in match:
                 # Try to replace some long names like "OpenOffice.org" which
                 # doesn't display nicely:
