@@ -48,8 +48,9 @@ class TMModel(BaseTMModel):
 
 
     # METHODS #
-    def query(self, tmcontroller, query_str):
-        # Figure out languages
+    def query(self, tmcontroller, unit):
+        # TODO: Figure out languages
+        query_str = unit.source
         if self.cache.has_key(query_str):
             self.emit('match-found', query_str, self.cache[query_str])
         else:
@@ -60,6 +61,8 @@ class TMModel(BaseTMModel):
         self.cache[query_str] = matches
         for match in matches:
             match['tmsource'] = self.shortname
+            if not isinstance(match['target'], unicode):
+                match['target'] = unicode(match['target'], 'utf-8')
         self.emit('match-found', query_str, matches)
 
     def push_store(self, store_controller):
