@@ -62,21 +62,24 @@ class TMModel(BaseTMModel):
 
 
     # METHODS #
-    def query(self, tmcontroller, query_str):
+    def query(self, tmcontroller, unit):
+        query_str = unit.source
         matches = []
         # Uncomment this if you don't trust the results
         #results = self._db.execute("""SELECT * FROM tinytm_get_fuzzy_matches('en', 'de', 'THE EUROPEAN ECONOMIC COMMUNITY', '', '')""")
         cursor = self._db_con.cursor()
         cursor.execute(
             """SELECT * FROM tinytm_get_fuzzy_matches(%s, %s, %s, '', '')""",
-            (self.source_lang, self.target_lang, query_str)
+            (self.source_lang, self.target_lang, query_str.encode('utf-8'))
         )
         for result in cursor.fetchall():
-            #print result
+            quality, source, target = result[:3]
+            if not isinstance(target, unicode):
+                target = unicode(target, 'utf-8')
             matches.append({
-                'source': result[1],
-                'target': result[2],
-                'quality': result[0],
+                'source': source,
+                'target': target,
+                'quality': quality,
                 'tmsource': self.display_name,
             })
 
