@@ -21,9 +21,9 @@
 import gobject
 import logging
 import os.path
-from translate.lang.data import forceunicode
+from translate.lang.data import forceunicode, normalize
 
-from virtaal.common import GObjectWrapper, pan_app
+from virtaal.common import GObjectWrapper
 from virtaal.controllers import BaseController, PluginController
 
 import models
@@ -36,7 +36,7 @@ class TMController(BaseController):
 
     __gtype_name__ = 'TMController'
     __gsignals__ = {
-        'start-query': (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, (gobject.TYPE_STRING,))
+        'start-query': (gobject.SIGNAL_RUN_FIRST, None, (object,))
     }
 
     QUERY_DELAY = 300
@@ -61,6 +61,7 @@ class TMController(BaseController):
 
     def _connect_plugin(self):
         self._store_loaded_id = self.main_controller.store_controller.connect('store-loaded', self._on_store_loaded)
+        self._store_closed_id = self.main_controller.store_controller.connect('store-closed', self._on_store_closed)
         if self.main_controller.store_controller.get_store() is not None:
             self._on_store_loaded(self.main_controller.store_controller)
             self.view._should_show_tmwindow = True
@@ -96,6 +97,7 @@ class TMController(BaseController):
     def accept_response(self, tmmodel, query_str, matches):
         """Accept a query-response from the model.
             (This method is used as Model-Controller communications)"""
+        query_str = forceunicode(query_str)
         if query_str != self.current_query or not matches:
             return
         # Perform some sanity checks on matches first
@@ -106,18 +108,21 @@ class TMController(BaseController):
                 match['tmsource'] = tmmodel.display_name
             match['query_str'] = query_str
 
-        curr_targets = [m['target'] for m in self.matches]
         anything_new = False
         for match in matches:
-            if match['target'] not in curr_targets:
+            curr_targets = [normalize(m['target']) for m in self.matches]
+            if normalize(match['target']) not in curr_targets:
                 # Let's insert at the end to prioritise existing matches over
                 # new ones. We rely on the guarantee of sort stability. This
                 # way an existing 100% will be above a new 100%.
                 self.matches.append(match)
                 anything_new = True
             else:
-                prevmatch = [m for m in self.matches if m['target'] == match['target']][0]
+                norm_match_target = normalize(match['target'])
+                prevmatch = [m for m in self.matches if normalize(m['target']) == norm_match_target][0]
                 if 'quality' not in prevmatch or not prevmatch['quality']:
+                    # Matches without quality are assumed to be less appropriate
+                    # (ie. MT matches) than matches with an associated quality.
                     self.matches.remove(prevmatch)
                     self.matches.append(match)
                     anything_new = True
@@ -165,7 +170,7 @@ class TMController(BaseController):
         self.current_query = self.unit.source
         self.matches = []
         self.view.clear()
-        self.emit('start-query', self.current_query)
+        self.emit('start-query', self.unit)
 
     def start_query(self):
         """Start a TM query after C{self.QUERY_DELAY} milliseconds."""
@@ -194,6 +199,9 @@ class TMController(BaseController):
         self.storecursor = cursor
         self.unit = cursor.deref()
 
+        if self.unit is None:
+            return
+
         if self.view.active and self.unit.istranslated():
             self.view.mnu_suggestions.set_active(False)
         elif not self.view.active and not self.unit.istranslated():
@@ -204,9 +212,16 @@ class TMController(BaseController):
     def _on_mode_selected(self, modecontroller, mode):
         self.view.update_geometry()
 
+    def _on_store_closed(self, storecontroller):
+        if hasattr(self, '_cursor_changed_id') and self.storecursor:
+            self.storecursor.disconnect(self._cursor_changed_id)
+        self.storecursor = None
+        self._cursor_changed_id = 0
+        self.view.hide()
+
     def _on_store_loaded(self, storecontroller):
         """Disconnect from the previous store's cursor and connect to the new one."""
-        if getattr(self, '_cursor_changed_id', None):
+        if getattr(self, '_cursor_changed_id', None) and self.storecursor:
             self.storecursor.disconnect(self._cursor_changed_id)
         self.storecursor = storecontroller.cursor
         self._cursor_changed_id = self.storecursor.connect('cursor-changed', self._on_cursor_changed)
