@@ -93,9 +93,18 @@ class OpenTranClient(gobject.GObject, HTTPClient):
         self.target_lang = None
         self.lang_negotiate(language, self._handle_target_lang)
 
+    def _loads_safe(self, response):
+        """Does the loading of the XML-RPC response, but handles exceptions."""
+        try:
+            (data,), _fish = xmlrpclib.loads(response)
+        except Exception, exc:
+            logging.debug('XML-RPC exception: %s' % (exc))
+            return None
+        return data
+
     def _handle_target_lang(self, request, response):
         language = request.id
-        (result,), fish = xmlrpclib.loads(response)
+        result = self._loads_safe(response)
         if result:
             self.target_lang = language
             #logging.debug("target language %s supported" % language)
@@ -111,7 +120,7 @@ class OpenTranClient(gobject.GObject, HTTPClient):
 
     def _handle_source_lang(self, request, response):
         language = request.id
-        (result,), fish = xmlrpclib.loads(response)
+        result = self._loads_safe(response)
         if result:
             self.source_lang = language
             #logging.debug("source language %s supported" % language)
@@ -126,28 +135,26 @@ class OpenTranClient(gobject.GObject, HTTPClient):
 
     def format_suggestions(self, id, response):
         """clean up open tran suggestion and use the same format as tmserver"""
-        (suggestions,), fish = xmlrpclib.loads(response)
+        suggestions = self._loads_safe(response)
+        if not suggestions:
+            return []
+        id = data.forceunicode(id)
         self.last_suggestions = suggestions
         results = []
         for suggestion in suggestions:
-            result = {}
-            result['target'] = suggestion['text']
-            if isinstance(result['target'], unicode):
-                result['target'] = result['target'].encode("utf-8")
-            result['tmsource'] = suggestion['projects'][0]['name']
-            result['source'] = suggestion['projects'][0]['orig_phrase']
             #check for fuzzyness at the 'flag' member:
             for project in suggestion['projects']:
                 if project['flags'] == 0:
                     break
             else:
                 continue
-            if isinstance(result['source'], unicode):
-                result['source'] = result['source'].encode("utf-8")
+            result = {}
+            result['target'] = data.forceunicode(suggestion['text'])
+            result['tmsource'] = suggestion['projects'][0]['name']
+            result['source'] = data.forceunicode(suggestion['projects'][0]['orig_phrase'])
             #open-tran often gives too many results with many which can't really be
             #considered to be suitable for translation memory
-            #FIXME: we should not have to decode here: it should be unicode
-            result['quality'] = self.comparer.similarity(id.decode('utf-8'), result['source'].decode('utf-8'), self.min_similarity)
+            result['quality'] = self.comparer.similarity(id, result['source'], self.min_similarity)
             if result['quality'] >= self.min_similarity:
                 results.append(result)
         results.sort(key=lambda match: match['quality'], reverse=True)
