@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2008-2009 Zuza Software Foundation
+# Copyright 2008-2010 Zuza Software Foundation
 #
 # This file is part of Virtaal.
 #
@@ -18,7 +18,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-import gobject
 import gtk
 import locale
 import os
@@ -28,16 +27,13 @@ from gtk import gdk
 from translate.storage import factory
 
 from virtaal import __version__
-from virtaal.views import recent
-from virtaal.common import pan_app, GObjectWrapper
+from virtaal.views import recent, theme
+from virtaal.common import pan_app
 from virtaal.support import openmailto
 
 from widgets.aboutdialog import AboutDialog
 from baseview import BaseView
 
-import pygtk
-pygtk.require("2.0")
-
 def fill_dialog(dialog, title='', message='', markup=''):
     if title:
         dialog.set_title(title)
@@ -125,6 +121,7 @@ class MainView(BaseView):
             # might want to disable the GTK one:
             #self.gui.get_widget('status_bar').set_property("has-resize-grip", False)
             try:
+                # FIXME: Rename the separators that were automatically named by Glade
                 import igemacintegration
                 # Move the menu bar to the mac menu
                 menubar = self.gui.get_widget('menubar')
@@ -150,24 +147,24 @@ class MainView(BaseView):
 
                 logging.debug("igemacintegration module not found. Expect zero integration with the mac desktop.")
 
-        # Create our events dictionary and connect it
-        dic = {
-            "on_mainwindow_destroy" : self._on_quit,
-            "on_mainwindow_delete" : self._on_quit,
-            "on_open_activate" : self._on_file_open,
-            "on_save_activate" : self._on_file_save,
-            "on_saveas_activate" : self._on_file_saveas,
-            "on_update_activate" : self._on_file_update,
-            "on_revert_activate" : self._on_file_revert,
-            "on_quit" : self._on_quit,
-            "on_menuitem_fullscreen_toggled" : self._on_fullscreen,
-            "on_about_activate" : self._on_help_about,
-            "on_tutorial_activate" : self._on_tutorial,
-            "on_localization_guide_activate" : self._on_localization_guide,
-            "on_menuitem_documentation_activate" : self._on_documentation,
-            "on_menuitem_report_bug_activate" : self._on_report_bug,
-        }
-        self.gui.signal_autoconnect(dic)
+        self.main_window.connect('destroy', self._on_quit)
+        self.main_window.connect('delete-event', self._on_quit)
+        # File menu signals
+        self.gui.get_widget('mnu_open').connect('activate', self._on_file_open)
+        self.gui.get_widget('mnu_save').connect('activate', self._on_file_save)
+        self.gui.get_widget('mnu_saveas').connect('activate', self._on_file_saveas)
+        self.gui.get_widget('mnu_close').connect('activate', self._on_file_close)
+        self.gui.get_widget('mnu_update').connect('activate', self._on_file_update)
+        self.gui.get_widget('mnu_revert').connect('activate', self._on_file_revert)
+        self.gui.get_widget('mnu_quit').connect('activate', self._on_quit)
+        # View menu signals
+        self.gui.get_widget('mnu_fullscreen').connect('activate', self._on_fullscreen)
+        # Help menu signals
+        self.gui.get_widget('mnu_documentation').connect('activate', self._on_documentation)
+        self.gui.get_widget('mnu_tutorial').connect('activate', self._on_tutorial)
+        self.gui.get_widget('mnu_localization_guide').connect('activate', self._on_localization_guide)
+        self.gui.get_widget('mnu_report_bug').connect('activate', self._on_report_bug)
+        self.gui.get_widget('mnu_about').connect('activate', self._on_help_about)
 
         self.menubar = self.gui.get_widget('menubar')
         self.status_bar = self.gui.get_widget("status_bar")
@@ -182,7 +179,7 @@ class MainView(BaseView):
 
         self.main_window.connect('window-state-event', self._on_window_state_event)
 
-        recent_files = self.gui.get_widget("recent_files")
+        recent_files = self.gui.get_widget("mnu_recent_files")
         recent.rc.connect("item-activated", self._on_recent_file_activated)
         recent_files.set_submenu(recent.rc)
 
@@ -190,6 +187,7 @@ class MainView(BaseView):
         self._create_dialogs()
         self._setup_key_bindings()
         self._track_window_state()
+        self.main_window.connect('style-set', self._on_style_set)
 
     def _create_dialogs(self):
         self.input_dialog = EntryDialog(self.main_window)
@@ -284,6 +282,9 @@ class MainView(BaseView):
             self._window_is_maximized = bool(event.new_window_state & gtk.gdk.WINDOW_STATE_MAXIMIZED)
         self.main_window.connect('window-state-event', on_state_event)
 
+    def _on_style_set(self, widget, prev_style):
+        theme.update_style(widget)
+
 
     # ACCESSORS #
     def add_accel_group(self, accel_group):
@@ -292,9 +293,9 @@ class MainView(BaseView):
         self.main_window.add_accel_group(accel_group)
 
     def set_saveable(self, value):
-        menuitem = self.gui.get_widget("save_menuitem")
+        menuitem = self.gui.get_widget("mnu_save")
         menuitem.set_sensitive(value)
-        menuitem = self.gui.get_widget("revert_menuitem")
+        menuitem = self.gui.get_widget("mnu_revert")
         menuitem.set_sensitive(value)
         filename = self.controller.get_store_filename()
         if filename:
@@ -415,6 +416,14 @@ class MainView(BaseView):
 
         return None, None
 
+    def open_file(self):
+        filename_and_uri = self.show_open_dialog()
+        if filename_and_uri:
+            filename, uri = filename_and_uri
+            self._uri = uri
+            return self.controller.open_file(filename, uri=uri)
+        return False
+
     def quit(self):
         if self._window_is_maximized:
             pan_app.settings.general['maximized'] = 1
@@ -452,7 +461,7 @@ class MainView(BaseView):
         if title:
             self.open_chooser.set_title(title)
 
-        if os.path.exists(pan_app.settings.general["lastdir"]):
+        if os.path.exists(pan_app.settings.general["lastdir"] or ""):
             self.open_chooser.set_current_folder(pan_app.settings.general["lastdir"])
 
         self.open_chooser.set_transient_for(self._top_window)
@@ -535,9 +544,7 @@ class MainView(BaseView):
             return 'save'
         elif response == gtk.RESPONSE_NO:
             return 'discard'
-        elif response == gtk.RESPONSE_CANCEL:
-            return 'cancel'
-        return ''
+        return 'cancel'
 
 
     # SIGNAL HANDLERS #
@@ -547,17 +554,14 @@ class MainView(BaseView):
         if getattr(self, '_store_loaded_handler_id ', None):
             main_controller.store_controller.disconnect(self._store_loaded_handler_id)
 
+        self._store_closed_handler_id = new_controller.connect('store-closed', self._on_store_closed)
         self._store_loaded_handler_id = new_controller.connect('store-loaded', self._on_store_loaded)
 
     def _on_documentation(self, _widget=None):
         openmailto.open("http://translate.sourceforge.net/wiki/virtaal/index")
 
-    def _on_file_open(self, _widget, destroyCallback=None):
-        filename_and_uri = self.show_open_dialog()
-        if filename_and_uri:
-            filename, uri = filename_and_uri
-            self._uri = uri
-            self.controller.open_file(filename, uri=uri)
+    def _on_file_open(self, _widget):
+        self.open_file()
 
     def _on_file_save(self, widget=None):
         # we force save us on potentially destructive file level
@@ -580,7 +584,10 @@ class MainView(BaseView):
             return True
         return False
 
-    def _on_file_update(self, _widget, destroyCallback=None):
+    def _on_file_close(self, widget=None):
+        self.controller.close_file()
+
+    def _on_file_update(self, _widget):
         filename_and_uri = self.show_open_dialog()
         if filename_and_uri:
             filename, uri = filename_and_uri
@@ -597,8 +604,7 @@ class MainView(BaseView):
             self.main_window.unfullscreen()
 
     def _on_tutorial(self, widget=None):
-        filename = pan_app.get_abs_data_filename(["virtaal", "tutorial.pot"])
-        self.controller.open_file(filename)
+        self.controller.open_tutorial()
 
     def _on_localization_guide(self, _widget=None):
         # Should be more redundent
@@ -624,9 +630,17 @@ class MainView(BaseView):
     def _on_report_bug(self, _widget=None):
         openmailto.open("http://bugs.locamotion.org/enter_bug.cgi?product=Virtaal&version=%s" % __version__.ver)
 
+    def _on_store_closed(self, store_controller):
+        self.gui.get_widget('mnu_saveas').set_sensitive(False)
+        self.gui.get_widget('mnu_close').set_sensitive(False)
+        self.gui.get_widget('mnu_update').set_sensitive(False)
+        self.status_bar.set_sensitive(False)
+        self.main_window.set_title(_('Virtaal'));
+
     def _on_store_loaded(self, store_controller):
-        self.gui.get_widget('saveas_menuitem').set_sensitive(True)
-        self.gui.get_widget('update_menuitem').set_sensitive(True)
+        self.gui.get_widget('mnu_saveas').set_sensitive(True)
+        self.gui.get_widget('mnu_close').set_sensitive(True)
+        self.gui.get_widget('mnu_update').set_sensitive(True)
         self.status_bar.set_sensitive(True)
         if getattr(self, '_uri', None):
             recent.rm.add_item(self._uri)
@@ -634,5 +648,5 @@ class MainView(BaseView):
             recent.rm.add_item('file://' + os.path.abspath(store_controller.store.filename))
 
     def _on_window_state_event(self, widget, event):
-        mnu_fullscreen = self.gui.get_widget('menuitem_fullscreen')
+        mnu_fullscreen = self.gui.get_widget('mnu_fullscreen')
         mnu_fullscreen.set_active(event.new_window_state & gdk.WINDOW_STATE_FULLSCREEN)
