@@ -35,22 +35,26 @@ class StoreView(BaseView):
     def __init__(self, controller):
         self.controller = controller
         # XXX: While I can't think of a better way to do this, the following line would have to do :/
-        self.parent_widget = self.controller.main_controller.view.gui.get_widget('scrolledwindow1')
+        self.parent_widget = self.controller.main_controller.view.gui.get_widget('scrwnd_storeview')
+
+        self.cursor = None
+        self._cursor_changed_id = 0
 
         self._init_treeview()
         self._add_accelerator_bindings()
         self.load_store(self.controller.store)
 
         self.controller.main_controller.view.main_window.connect('configure-event', self._treeview.on_configure_event)
+        self.controller.main_controller.view.main_window.connect('style-set', self._on_style_set)
 
     def _init_treeview(self):
         self._treeview = StoreTreeView(self)
 
     def _add_accelerator_bindings(self):
-        gtk.accel_map_add_entry("<Virtaal>/Navigation/Up", gtk.accelerator_parse("Up")[0], gdk.CONTROL_MASK)
-        gtk.accel_map_add_entry("<Virtaal>/Navigation/Down", gtk.accelerator_parse("Down")[0], gdk.CONTROL_MASK)
-        gtk.accel_map_add_entry("<Virtaal>/Navigation/PgUp", gtk.accelerator_parse("Page_Up")[0], gdk.CONTROL_MASK)
-        gtk.accel_map_add_entry("<Virtaal>/Navigation/PgDown", gtk.accelerator_parse("Page_Down")[0], gdk.CONTROL_MASK)
+        gtk.accel_map_add_entry("<Virtaal>/Navigation/Up", gtk.accelerator_parse("Up")[0], gtk.gdk.CONTROL_MASK)
+        gtk.accel_map_add_entry("<Virtaal>/Navigation/Down", gtk.accelerator_parse("Down")[0], gtk.gdk.CONTROL_MASK)
+        gtk.accel_map_add_entry("<Virtaal>/Navigation/PgUp", gtk.accelerator_parse("Page_Up")[0], gtk.gdk.CONTROL_MASK)
+        gtk.accel_map_add_entry("<Virtaal>/Navigation/PgDown", gtk.accelerator_parse("Page_Down")[0], gtk.gdk.CONTROL_MASK)
 
         self.accel_group = gtk.AccelGroup()
         self.accel_group.connect_by_path("<Virtaal>/Navigation/Up", self._treeview._move_up)
@@ -74,10 +78,6 @@ class StoreView(BaseView):
 
 
     # ACCESSORS #
-    def _get_cursor(self):
-        return self.controller.cursor
-    cursor = property(_get_cursor)
-
     def get_store(self):
         return self.store
 
@@ -86,20 +86,32 @@ class StoreView(BaseView):
 
 
     # METHODS #
+    def hide(self):
+        self.parent_widget.props.visible = False
+        self.load_store(None)
+
     def load_store(self, store):
         self.store = store
         if store:
             self._treeview.set_model(store)
             self._set_menu_items_sensitive(True)
-            self.cursor.connect('cursor-changed', self._on_cursor_change)
+            self.cursor = self.controller.cursor
+            self._cursor_changed_id = self.cursor.connect('cursor-changed', self._on_cursor_change)
+        else:
+            if self._cursor_changed_id and self.cursor:
+                self.cursor.disconnect(self._cursor_changed_id)
+                self.cursor = None
+            self._set_menu_items_sensitive(False)
+            self._treeview.set_model(None)
 
     def show(self):
         child = self.parent_widget.get_child()
-        if child is not self._treeview:
+        if child and child is not self._treeview:
             self.parent_widget.remove(child)
             child.destroy()
+        if not self._treeview.parent:
             self.parent_widget.add(self._treeview)
-        self._treeview.show()
+        self.parent_widget.show_all()
         self._treeview.select_index(0)
 
         if self._treeview.get_model():
@@ -114,3 +126,9 @@ class StoreView(BaseView):
     # EVENT HANDLERS #
     def _on_cursor_change(self, cursor):
         self._treeview.select_index(cursor.index)
+
+    def _on_style_set(self, widget, prev_style):
+        # The following color change is to reduce the flickering seen when
+        # changing units. It's not the perfect cure, but helps a lot.
+        # http://bugs.locamotion.org/show_bug.cgi?id=1412
+        self._treeview.modify_base(gtk.STATE_ACTIVE, widget.style.bg[gtk.STATE_NORMAL])
