@@ -21,7 +21,7 @@
 import gtk
 import logging
 import re
-from gobject import idle_add, GObject, SIGNAL_RUN_FIRST, TYPE_PYOBJECT
+from gobject import idle_add, PARAM_READWRITE, SIGNAL_RUN_FIRST, TYPE_PYOBJECT
 from translate.lang import factory
 try:
     import gtkspell
@@ -30,10 +30,8 @@ except ImportError, e:
 
 from virtaal.common import GObjectWrapper, pan_app
 
-import markup
 import rendering
 from baseview import BaseView
-from widgets.label_expander import LabelExpander
 from widgets.textbox import TextBox
 
 
@@ -49,6 +47,9 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         'unit-done':      (SIGNAL_RUN_FIRST, None, (TYPE_PYOBJECT,)),
         'target-focused': (SIGNAL_RUN_FIRST, None, (int,)),
     }
+    __gproperties__ = {
+        'editing-canceled': (bool, 'Editing cancelled', 'Editing was cancelled', False, PARAM_READWRITE),
+    }
 
     first_word_re = re.compile("(?m)(?u)^(<[^>]+>|\\\\[nt]|[\W$^\n])*(\\b|\\Z)")
     """A regular expression to help us find a meaningful place to position the
@@ -156,6 +157,23 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         # store is loaded. See _set_menu_items_sensitive() for more activation.
         self._set_menu_items_sensitive(False)
 
+        def on_store_closed(*args):
+            mnu_next.set_sensitive(False)
+            mnu_prev.set_sensitive(False)
+            mnu_transfer.set_sensitive(False)
+            self.mnu_cut.set_sensitive(False)
+            self.mnu_copy.set_sensitive(False)
+            self.mnu_paste.set_sensitive(False)
+        def on_store_loaded(*args):
+            mnu_next.set_sensitive(True)
+            mnu_prev.set_sensitive(True)
+            mnu_transfer.set_sensitive(True)
+            self.mnu_cut.set_sensitive(True)
+            self.mnu_copy.set_sensitive(True)
+            self.mnu_paste.set_sensitive(True)
+        self.controller.main_controller.store_controller.connect('store-closed', on_store_closed)
+        self.controller.main_controller.store_controller.connect('store-loaded', on_store_loaded)
+
 
     # ACCESSORS #
     def is_modified(self):
@@ -185,13 +203,14 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         if textbox.selector_textbox is not textbox and \
             textbox.selector_textbox.selected_elem is not None:
             textbox.insert_translation(textbox.selector_textbox.selected_elem)
-            textbox.selector_textbox.move_elem_selection(1)
+            textbox.move_elem_selection(1)
             return
 
         undocontroller = self.controller.main_controller.undo_controller
         lang = factory.getlanguage(self.controller.main_controller.lang_controller.target_lang.code)
 
-        tgt = self.unit.rich_source[0].copy()
+        selector_textbox_index = textbox.selector_textboxes.index(textbox.selector_textbox)
+        tgt = self.unit.rich_source[selector_textbox_index].copy()
         placeables_controller = self.controller.main_controller.placeables_controller
         parsers = placeables_controller.get_parsers_for_textbox(textbox)
         placeables_controller.apply_parsers(tgt, parsers)
@@ -252,7 +271,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         self.disable_signals(['modified', 'insert-text', 'delete-text'])
         self._update_editor_gui()
         self.enable_signals(['modified', 'insert-text', 'delete-text'])
-        self._widgets['tbl_editor'].reparent(self)
+        self._widgets['vbox_editor'].reparent(self)
 
         if unit is not None:
             for i in range(len(self.targets)):
@@ -301,7 +320,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         if not getattr(self, '_widgets', None):
             self._widgets = {}
 
-        widget_names = ('tbl_editor', 'vbox_middle', 'vbox_sources', 'vbox_targets', 'vbox_options', 'vbox_right')
+        widget_names = ('vbox_editor', 'vbox_middle', 'vbox_sources', 'vbox_targets', 'vbox_options', 'vbox_right')
 
         for name in widget_names:
             self._widgets[name] = self.gui.get_widget(name)
@@ -364,7 +383,10 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
                 spell = None
                 try:
                     spell = gtkspell.get_from_text_view(text_view)
-                except SystemError:
+                except SystemError, e:
+                    # At least on Mandriva .get_from_text_view() sometimes returns
+                    # a SystemError without a description. Things seem to work fine
+                    # anyway, so let's ignore it and hope for the best.
                     pass
                 if not spell is None:
                     spell.detach()
@@ -379,15 +401,19 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
             spell = None
             try:
                 spell = gtkspell.get_from_text_view(text_view)
-            except SystemError:
+            except SystemError, e:
+                # At least on Mandriva .get_from_text_view() sometimes returns
+                # a SystemError without a description. Things seem to work fine
+                # anyway, so let's ignore it and hope for the best.
                 pass
             if spell is None:
-                spell = gtkspell.Spell(text_view)
-            spell.set_language(language)
-            spell.recheck_all()
+                spell = gtkspell.Spell(text_view, language)
+            else:
+                spell.set_language(language)
+                spell.recheck_all()
             text_view.spell_lang = language
-        except Exception:
-            logging.exception("Could not initialize spell checking")
+        except Exception, e:
+            logging.exception("Could not initialize spell checking", e)
             gtkspell = None
 
     if not pan_app.DEBUG:
@@ -444,6 +470,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
             target = self._create_textbox(u'', editable=True, role='target', scroll_policy=gtk.POLICY_AUTOMATIC)
             textbox = target.get_child()
             textbox.modify_font(rendering.get_target_font_description())
+            textbox.selector_textboxes = self.sources
             textbox.selector_textbox = self.sources[0]
             textbox.connect('paste-clipboard', self._on_textbox_paste_clipboard, i)
             textbox.connect('text-inserted', self._on_target_insert_text, i)
@@ -592,6 +619,8 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
             num_unit_targets = len(self.unit.target.strings)
             nplurals = self.controller.main_controller.lang_controller.target_lang.nplurals
 
+        visible_sources = [src for src in self.sources if src.props.visible]
+
         rich_target = self.unit.rich_target
         rich_target_len = len(rich_target)
         for i in range(self.MAX_TARGETS):
@@ -603,6 +632,8 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
                 self.targets[i].modify_font(rendering.get_target_font_description())
                 self.targets[i].set_text(targetstr)
                 self.targets[i].parent.show_all()
+                self.targets[i].selector_textboxes = visible_sources
+                self.targets[i].selector_textbox = visible_sources[0]
                 #logging.debug('Showing target #%d: %s' % (i, self.targets[i]))
             else:
                 # outside plural range
@@ -637,6 +668,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
             # Clear selected elements
             self.editing_done()
             return True
+        self.must_advance = False
         return False
 
     def _on_target_changed(self, buffer, index):
@@ -644,7 +676,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
         nplurals = self.controller.main_controller.lang_controller.target_lang.nplurals
         if tgt.elem is not None:
             rich_target = self.unit.rich_target
-            if len(rich_target) < nplurals:
+            if self.unit.hasplural() and len(rich_target) < nplurals:
                 # pad the target with empty strings
                 rich_target += (nplurals - len(rich_target)) * [u""]
             rich_target[index] = tgt.elem
@@ -686,7 +718,7 @@ class UnitView(gtk.EventBox, GObjectWrapper, gtk.CellEditable, BaseView):
             'selection_offset': selb_iter.get_offset()
         }
 
-        #logging.debug('emit("paste-start", old_text="%s", offsets=%d, target_num=%d)' % (old_text, offsets, target_num))
+        #logging.debug('emit("paste-start", old_text="%s", offsets=%s, target_num=%d)' % (old_text, offsets, target_num))
         self.emit('paste-start', old_text, offsets, target_num)
 
     def _on_textbox_focused(self, textbox, event):
