@@ -22,11 +22,11 @@ import gobject
 import gtk
 import logging
 import pango
-from gtk import gdk
 from translate.lang import factory
 
 from virtaal.support.simplegeneric import generic
 from virtaal.views import markup, rendering
+from virtaal.views.theme import current_theme
 from virtaal.common import pan_app
 
 
@@ -260,24 +260,28 @@ class StoreTreeView(gtk.TreeView):
 
         if selected[1] is None or (selected_path and selected_path != newpath):
             #logging.debug('select_index()->self.set_cursor(path="%s")' % (newpath))
+            # XXX: Both of the "self.set_cursor()" calls below are necessary in
+            #      order to have both bug 869 fixed and keep search highlighting
+            #      in working order. After exhaustive inspection of the
+            #      interaction between emitted signals involved, Friedel and I
+            #      still have no idea why exactly it is needed. This just seems
+            #      to be the correct GTK black magic incantation to make it
+            #      "work".
             self.set_cursor(newpath, self.get_columns()[0], start_editing=True)
-            self._activate_editing_path(newpath)
+            self.get_model().set_editable(newpath)
+            def change_cursor():
+                self.set_cursor(newpath, self.get_columns()[0], start_editing=True)
+                self._waiting_for_row_change -= 1
+            self._waiting_for_row_change += 1
+            gobject.idle_add(change_cursor, priority=gobject.PRIORITY_DEFAULT_IDLE)
 
     def set_model(self, storemodel):
-        model = StoreTreeModel(storemodel)
+        if storemodel:
+            model = StoreTreeModel(storemodel)
+        else:
+            model = gtk.ListStore(object)
         super(StoreTreeView, self).set_model(model)
 
-    def _activate_editing_path(self, new_path):
-        """Activates the given path for editing."""
-        # get the index of the translation unit in the translation store
-        #self.get_model().set(self.get_model().get_iter(new_path), COLUMN_EDITABLE, True)
-        self.get_model().set_editable(new_path)
-        def change_cursor():
-            self.set_cursor(new_path, self.get_columns()[0], start_editing=True)
-            self._waiting_for_row_change -= 1
-        self._waiting_for_row_change += 1
-        gobject.idle_add(change_cursor, priority=gobject.PRIORITY_DEFAULT_IDLE)
-
     def _keyboard_move(self, offset):
         if not self.view.controller.get_store():
             return
@@ -293,8 +297,6 @@ class StoreTreeView(gtk.TreeView):
         try:
             #self._owner.set_statusbar_message(self.document.mode_cursor.move(offset))
             self.view.cursor.move(offset)
-            path = self.get_model().store_index_to_path(self.view.cursor.index)
-            self._activate_editing_path(path)
         except IndexError:
             pass
 
@@ -435,7 +437,7 @@ class StoreCellRenderer(gtk.GenericCellRenderer):
 
     def _set_unit(self, value):
         if value.isfuzzy():
-            self.props.cell_background = "gray"
+            self.props.cell_background = current_theme['fuzzy_row_bg']
             self.props.cell_background_set = True
         else:
             self.props.cell_background_set = False
