@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2009 Zuza Software Foundation
+# Copyright 2009-2010 Zuza Software Foundation
 #
 # This file is part of Virtaal.
 #
@@ -24,9 +24,11 @@ from gobject import SIGNAL_RUN_FIRST, SIGNAL_RUN_LAST
 
 from translate.misc.typecheck import accepts, Self, IsOneOf
 from translate.storage.placeables import StringElem, parse as elem_parse
+from translate.storage.placeables.terminology import TerminologyPlaceable
 from translate.lang import data
 
 from virtaal.views import placeablesguiinfo
+from virtaal.views.theme import current_theme
 
 
 class TextBox(gtk.TextView):
@@ -77,6 +79,7 @@ class TextBox(gtk.TextView):
         self.refresh_cursor_pos = -1
         self.role = role
         self.selector_textbox = selector_textbox or self
+        self.selector_textboxes = [selector_textbox or self]
         self.selected_elem = None
         self.selected_elem_index = None
         self._suggestion = None
@@ -141,7 +144,7 @@ class TextBox(gtk.TextView):
             end_iter = self.buffer.get_end_iter()
         return data.forceunicode(self.buffer.get_text(start_iter, end_iter))
 
-    @accepts(Self(), [[IsOneOf(StringElem, str, unicode)]])
+    @accepts(Self(), IsOneOf(StringElem, str, unicode))
     def set_text(self, text):
         """Set the text rendered in this text box.
             Uses C{gtk.TextBuffer.set_text()}.
@@ -168,7 +171,7 @@ class TextBox(gtk.TextView):
 
 
     # METHODS #
-    @accepts(Self(), [StringElem])
+    @accepts(Self(), IsOneOf(StringElem, unicode))
     def add_default_gui_info(self, elem):
         """Add default GUI info to string elements in the tree that does not
             have any GUI info.
@@ -191,7 +194,7 @@ class TextBox(gtk.TextView):
         for sub in elem.sub:
             self.add_default_gui_info(sub)
 
-    @accepts(Self(), [StringElem, bool])
+    @accepts(Self(), StringElem, bool)
     def apply_gui_info(self, elem, include_subtree=True):
         offset = self.elem.gui_info.index(elem)
         #logging.debug('offset for %s: %d' % (repr(elem), offset))
@@ -243,6 +246,9 @@ class TextBox(gtk.TextView):
 
         self.emit('after-apply-gui-info', elem)
 
+    def get_cursor_position(self):
+        return self.buffer.props.cursor_position
+
     def hide_suggestion(self):
         if not self.suggestion_is_visible():
             return
@@ -254,7 +260,7 @@ class TextBox(gtk.TextView):
         self.buffer.delete(*selection)
         self.buffer.handler_unblock_by_func(self._on_delete_range)
 
-    @accepts(Self(), [StringElem])
+    @accepts(Self(), IsOneOf(StringElem, TerminologyPlaceable))
     def insert_translation(self, elem):
         selection = self.buffer.get_selection_bounds()
         if selection:
@@ -307,16 +313,39 @@ class TextBox(gtk.TextView):
         self.refresh_cursor_pos = cursor_pos
         self.refresh()
 
-    @accepts(Self(), [int])
+    @accepts(Self(), int)
     def move_elem_selection(self, offset):
+        direction = offset/abs(offset) # Reduce offset to one of -1, 0 or 1
+        st_index = self.selector_textboxes.index(self.selector_textbox)
+        st_len = len(self.selector_textboxes)
+
         if self.selector_textbox.selected_elem_index is None:
             if offset <= 0:
+                if offset < 0 and st_len > 1:
+                    self.selector_textbox = self.selector_textboxes[(st_index + direction) % st_len]
                 self.selector_textbox.select_elem(offset=offset)
             else:
                 self.selector_textbox.select_elem(offset=offset-1)
         else:
             self.selector_textbox.select_elem(offset=self.selector_textbox.selected_elem_index + offset)
 
+        if self.selector_textbox.selected_elem_index is None and direction >= 0:
+            self.selector_textbox = self.selector_textboxes[(st_index + direction) % st_len]
+        self.__color_selector_textboxes()
+
+    def __color_selector_textboxes(self, *args):
+        """Put a highlighting border around the current selector text box."""
+        if not hasattr(self, 'selector_color'):
+            self.selector_color = gtk.gdk.Color(current_theme['selector_textbox'])
+        if not hasattr(self, 'nonselector_color'):
+            self.nonselector_color = self.parent.style.bg[gtk.STATE_NORMAL]
+
+        for selector in self.selector_textboxes:
+            if selector is self.selector_textbox:
+                selector.parent.modify_bg(gtk.STATE_NORMAL, self.selector_color)
+            else:
+                selector.parent.modify_bg(gtk.STATE_NORMAL, self.nonselector_color)
+
     def place_cursor(self, cursor_pos):
         cursor_iter = self.buffer.get_iter_at_offset(cursor_pos)
 
@@ -356,19 +385,21 @@ class TextBox(gtk.TextView):
 
         self.emit('refreshed', self.elem)
 
-    @accepts(Self(), [[StringElem, None], [int, None]])
+    @accepts(Self(), IsOneOf(StringElem, type(None)), IsOneOf(int, type(None)))
     def select_elem(self, elem=None, offset=None):
         if elem is not None and offset is not None:
             raise ValueError('Only one of "elem" or "offset" may be specified.')
 
         if elem is None and offset is None:
             # Clear current selection
+            #logging.debug('Clearing selected placeable from %s' % (repr(self)))
             if self.selected_elem is not None:
                 #logging.debug('Selected item *was* %s' % (repr(self.selected_elem)))
                 self.selected_elem.gui_info = None
                 self.add_default_gui_info(self.selected_elem)
                 self.selected_elem = None
             self.selected_elem_index = None
+            self.emit('element-selected', self.selected_elem)
             return
 
         filtered_elems = [e for e in self.elem.depth_first() if e.__class__ not in self.unselectables]
@@ -376,9 +407,14 @@ class TextBox(gtk.TextView):
             return
 
         if elem is None and offset is not None:
+            if self.selected_elem_index is not None and not (0 <= offset < len(filtered_elems)):
+                # Clear selection when we go past the first or last placeable
+                self.select_elem(None)
+                self.apply_gui_info(self.elem)
+                return
             return self.select_elem(elem=filtered_elems[offset % len(filtered_elems)])
 
-        if not elem in filtered_elems:
+        if elem not in filtered_elems:
             return
 
         # Reset the default tag for the previously selected element
@@ -395,10 +431,10 @@ class TextBox(gtk.TextView):
         self.selected_elem = elem
         #logging.debug('Selected element: %s (%s)' % (repr(self.selected_elem), unicode(self.selected_elem)))
         if not hasattr(elem, 'gui_info') or not elem.gui_info:
-            elem.gui_info = placeablesguiinfo.StringElemGUI(elem, self, fg='#000000', bg='#90ee90')
+            elem.gui_info = placeablesguiinfo.StringElemGUI(elem, self, fg=current_theme['selected_placeable_fg'], bg=current_theme['selected_placeable_bg'])
         else:
-            elem.gui_info.fg = '#000000'
-            elem.gui_info.bg = '#90ee90'
+            elem.gui_info.fg = current_theme['selected_placeable_fg']
+            elem.gui_info.bg = current_theme['selected_placeable_bg']
         self.apply_gui_info(self.elem, include_subtree=False)
         self.apply_gui_info(self.elem)
         self.apply_gui_info(elem, include_subtree=False)
@@ -435,7 +471,7 @@ class TextBox(gtk.TextView):
                 self.suggestion['offset'] >= 0 and \
                 self.suggestion['offset'] == start_offset
 
-    @accepts(Self(), [[StringElem, basestring, None]])
+    @accepts(Self(), IsOneOf(StringElem, basestring, type(None)))
     def update_tree(self, text=None):
         if not self.placeables_controller:
             return
@@ -746,11 +782,6 @@ class TextBox(gtk.TextView):
                 if event.keyval == keyval and filtered_state == state:
                     evname = name
 
-        if evname == 'alt-left':
-            self.move_elem_selection(-1)
-        elif evname == 'alt-right':
-            self.move_elem_selection(1)
-
         return self.emit('key-pressed', event, evname)
 
     def _on_event_remove_suggestion(self, *args):
